@@ -1,10 +1,10 @@
 from __future__ import annotations
 
 import re
+import secrets
 import string
 from collections.abc import Iterable
 from pathlib import Path
-from secrets import choice
 from typing import Final, NamedTuple
 
 import pytest
@@ -107,6 +107,11 @@ def generate_random_token_value() -> str:
     token = []
     valid_chars = string.ascii_letters + string.digits + "_-"
     for length_range in (range(24, 28), [6], range(27, 40)):
-        substring_range = range(choice(length_range))
-        token.append("".join(choice(valid_chars) for _ in substring_range))
+        substring_range = range(secrets.choice(length_range))
+        token.append("".join(secrets.choice(valid_chars) for _ in substring_range))
     return ".".join(token)
+
+
+def generate_random_text(length: int) -> str:
+    valid_chars = string.ascii_letters + string.digits + string.punctuation
+    return "".join(secrets.choice(valid_chars) for _ in range(length))
